// Package consts ...
//
// Description : consts ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 2023-02-07 21:43
//
// @see https://www.iana.org/assignments/media-types/media-types.xhtml
//
// @see http://www.jsons.cn/contenttype/
package consts

const (
	MimeTypeNone = "none"

	// MimeTypeAudioAcp .acp 后缀的文件
	// 编码的高效率高级音频编码（ HE-AAC ）版本1格式的音频文件（称为“ aacPlus的”）;类似于.AAC文件，但压缩和用于流优化音频，用于互联网广播和其他在线音乐流。
	MimeTypeAudioAcp = "audio/x-mei-aac"
	// MimeTypeAudioAiff .aif / .aiff 后缀的文件
	// AIF文件是以音频交换文件格式（AIFF）保存的音频文件。它包含类似于.WAV文件的未压缩高质量音频，通常用于存储标准CD音频。
	// @see https://www.wenjianbaike.com/aif.html
	MimeTypeAudioAiff = "audio/aiff"
	// MimeTypeTextAsa .asa 后缀文件
	// asa是ASP的一个全局应用文件。主要是定义Session对象和Application对象，以及相应的事件。
	// @see https://baike.baidu.com/item/asa/23604079?fr=aladdin
	MimeTypeTextAsa = "text/asa"
	// MimeTypeTextAsp .asp 后缀文件
	// ASP即Active Server Pages，是Microsoft公司开发的服务器端脚本环境，可用来创建动态交互式网页并建立强大的web应用程序
	// @see https://baike.baidu.com/item/asp/128906?fromModule=lemma_search-box
	MimeTypeTextAsp = "text/asp"
	// MimeTypeAudioAu .au后缀的文件
	// AU是Sun Microsystems为Unix平台开发的一种音频文件格式，通常在Sun或其他基于Unix系统的计算机上使用。AU文件和.WAV文件非常相像，并已被大多数的音频播放和编辑软件（例如Adobe Audition、QuickTime）所支持。
	// @see https://www.wenjianbaike.com/au.html
	MimeTypeAudioAu = "audio/basic"
	// MimeTypeApplicationAwf .awf后缀文件
	// Flash动画的源文件的后缀名是fla ，而导出生成的可发布的动画文件的后缀名是awf。
	// @see https://www.yebaike.com/22/489195.html
	MimeTypeApplicationAwf = "application/vnd.adobe.workflow"
	// MimeTypeApplicationBmp .bmp后缀文件
	// BMP文件是以微软开发的位图（Bitmap）图像格式保存的图片。BMP文本包含未压缩的图像数据，支持可变颜色位深度和图像元数据的单色和彩色图像。BMP是Windows系统中广泛使用的图像格式。
	// @see https://www.wenjianbaike.com/bmp.html
	MimeTypeApplicationBmp = "application/vnd.adobe.workflow"
	// MimeTypeApplicationC4t .c4t后缀文件
	MimeTypeApplicationC4t = "application/x-c4t"
	// MimeTypeApplicationCal .cal 后缀文件
	MimeTypeApplicationCal = "application/application/x-cals"
	// MimeTypeApplicationCdf .cdf 后缀文件
	MimeTypeApplicationCdf = "application/x-netcdf"
	// MimeTypeApplicationCel .cel后缀文件
	MimeTypeApplicationCel = "application/x-cel"
	// MimeTypeApplicationCg4 .cg4后缀文件
	MimeTypeApplicationCg4 = "application/x-g4"
	// MimeTypeApplicationCit .cit后缀文件
	MimeTypeApplicationCit = "application/x-cit"
	// MimeTypeTextXml .cml .xml .dcd .ent 后缀文件
	MimeTypeTextXml = "text/xml"
	// MimeTypeApplicationCmx .cmx 后缀文件
	MimeTypeApplicationCmx = "application/x-cmx"
	// MimeTypeApplicationCrl .crl 后缀文件
	MimeTypeApplicationCrl = "application/pkix-crl"
	// MimeTypeApplicationCsi .csi 后缀文件
	MimeTypeApplicationCsi = "application/x-csi"
	// MimeTypeApplicationCut .cut 后缀文件
	MimeTypeApplicationCut = "application/x-cut"
	// MimeTypeApplicationDbm .dbm 后缀文件
	MimeTypeApplicationDbm = "application/x-dbm"
	// MimeTypeApplicationDer .der 后缀文件
	MimeTypeApplicationDer = "application/x-x509-ca-cert"
	// MimeTypeApplicationDib .dib 后缀文件
	MimeTypeApplicationDib = "application/x-dib"
	// MimeTypeApplicationDoc .doc 后缀文件
	MimeTypeApplicationDoc = "application/msword"
	// MimeTypeApplicationDrw .drw 后缀文件
	MimeTypeApplicationDrw = "application/x-drw"
	// MimeTypeModelDwf .dwf 后缀文件
	MimeTypeModelDwf = "Model/vnd.dwf"
	// MimeTypeApplicationDwg .dwg 后缀文件
	MimeTypeApplicationDwg = "application/x-dwg"
	// MimeTypeApplicationDxf .dxf 后缀文件
	MimeTypeApplicationDxf = "application/x-dxf"
	// MimeTypeApplicationEmf .emf 后缀文件
	MimeTypeApplicationEmf = "application/x-emf"
	// MimeTypeApplicationEps .eps 后缀文件
	MimeTypeApplicationEps = "application/x-ps"
	// MimeTypeApplicationEtd .etd 后缀文件
	MimeTypeApplicationEtd = "application/x-ebx"
	// MimeTypeOctetStream 二进制流数据
	MimeTypeOctetStream = "application/octet-stream"
	// MimeTypeImageFax .fax 后缀文件
	MimeTypeImageFax = "image/fax"

	// MimeTypeImageJpeg jpeg图片
	MimeTypeImageJpeg = "image/jpeg"
	// MimeTypeImagePng png 图片
	MimeTypeImagePng = "image/png"
	// MimeTypeJson json数据格式
	MimeTypeJson = "application/json"
	// MimeTypeTextPlain text/plain
	MimeTypeTextPlain = "text/plain"
	// MimeTypeXWWWFormUrlencoded  <form encType=””>中默认的encType，form表单数据被编码为key/value格式发送到服务器（表单默认的提交数据的格式）
	MimeTypeXWWWFormUrlencoded = "application/x-www-form-urlencoded"
	// MimeTypeXml xml请求方式
	MimeTypeXml = "application/xml"
	// MimeTypeAcc acc音频
	MimeTypeAcc = "audio/acc"
	// MimeTypeAbw .abw后缀的文件
	// 文件扩展名名以.abw/.abw.crashed/.abw.gz结尾的文件是由AbiSource这款开源文字处理软件创建的文件格式。
	// AbiWord是一个免费的文字处理程序，类似于微软的Word， 是适用于各种各样的文字处理任务的专业办公软件。
	// 支持中文等全球多种语言，并支持Windows、Linux、Mac OS等多种操作系统平台。
	MimeTypeAbw = "application/x-abiword"
	// MimeType123 .123后缀文件
	// Open Source 软件包开发了 123文件扩展名，也称为 Lotus 1-2-3 Spreadsheet 文件Gnumeric 。
	// @see https://www.fileviewpro.com/zh-cn/file-extension-123/
	MimeType123 = "application/vnd.lotus-1-2-3"
	// MimeTypeImage3ds .3ds后缀文件
	// Adobe Systems Incorporated软件系列创建了3D Studio Scene (3DS) Adobe Photoshop CC 文件。
	// @see https://www.fileviewpro.com/zh-cn/file-extension-3ds
	MimeTypeImage3ds = "image/x-3ds"
	// MimeTypeVideo3gpp .3g2/.3ga/.3gp/.3gpp文件
	// 3GP（3GPP文件格式）是第三代合作伙伴项目计划（3rd Generation Partnership Project ，简称3GPP）为3G UMTS多媒体服务定义的一种多媒体容器格式，主要应用于3G移动电话，但也能在一些2G和4G手机上播放。
	// @see https://baike.baidu.com/item/3gp/203418?fr=aladdin
	MimeTypeVideo3gpp = "video/3gpp’"
)
